/*
  Hummidity Sensor Interface
  by Xavi Domínguez
  Arduino + Processing
  Based on this tutorial: http://diymakers.es/arduino-processing-primeros-pasos/
*/
 
import processing.serial.*; //Import Serial library
 
Serial port; //Serial port name // object
 
PrintWriter output;  //Text file for writing sensor data
 
int rquad=40; //Button radio ( width )
int xquad=200;  //Button X position 
int yquad=200;  //Button Y position
boolean overRect = false; //Check if mouse is over button or not
 
//Button colors
int red=100;
int green=100;
int blue=100;
 
boolean status=false; //Button status ( on / off led )
String texto="LED OFF";//LED text status
 
int xlogo=400;//Logo X position
int ylogo=50;//Logo Y position
 
int valor;//Sensor value
 
//Sensor color values
float rojo;
float verde;
float azul;
 
void setup()
{
  println(Serial.list()); //Serail port list
  port = new Serial(this, Serial.list()[1], 9600); //Open first serial port from USB
   
  output = createWriter("hummidity_data.txt"); //Create Text file . By default in same sketch folder
   
  size(800, 400); // Interface window ( 800 x 400 pixels )
}
 
void draw()
{
  background(0,0,0);//Background color
    
  if(mouseX > xquad-rquad && mouseX < xquad+rquad &&  //Check if mouse is over the button
     mouseY > yquad-rquad && mouseY < yquad+rquad)
     {
       overRect=true;  //If over then true
       stroke(0,0,255);  //Button border
     }
   else
   {
     overRect=false;  //If not then false
     stroke(255,255,255);  //Button border
   }
   
  //Fill button color
  fill(red,green,blue);
  rectMode(RADIUS); //Function to define width,heig radio ( distance from center to a side )
  rect(xquad,yquad,rquad,rquad);
   
  //LED STATUS TEXT
  fill(255,255,255);
  PFont f = loadFont("helvetica_hummidity.vlw");//Tipo de fuente
  textFont(f, 20);
  text(texto, 170, 270);
   
  //FABKIDS LOGO
  imageMode(CENTER);//Image coordinates in the center
  PImage imagen=loadImage("logo.png");
  image(imagen,xlogo,ylogo,200,100);
 
  //Getting data sensor from Arduino
  if(port.available() > 0) // si hay algún dato disponible en el puerto
   {
     valor=port.read();//Read data and save
   }
   //Data visualization
   text("Hummidity Sensor =",290,200);
   text(valor, 520, 200);
 
    
   //Writing data in the text file
   output.print(valor + " hummidity sensor     ");
   output.print(hour( )+":");
   output.print(minute( )+":");
   output.println(second( ));
   output.println("");
    
  // Data sensor sphere
  float temp = map (valor, 0,900, 0, 1024);
  rojo=temp;
  verde=temp*-1 + 255;
  azul=temp*-1 + 255;
  //Sphere ---> ellipse
  noStroke();
  fill(rojo,verde,azul);
  ellipseMode(CENTER);
  ellipse(590,193,20,20);
}
 
void mousePressed()  //Mouse pressed event
{
  if (overRect==true) //If mouse is inside button
  {
    status=!status; //Change LED status -> if true then false ... if false then true
    port.write("A"); //Send A to Arduino for ON/OFF LED
    if(status==true)
    {
      //Color button
      red=0;
      green=0;
      blue=255;
      texto="LED ON";
    }
    if(status==false)
    {
      //Color button
      red=100;
      green=100;
      blue=100;
      texto="LED OFF";
    }
  }
}
 
void keyPressed() // Key pressed event
{
  if(key=='w'||key=='W')
  {
        ylogo--; //Fabkids logo up
  }
  else if(key=='s'||key=='S')
  {
        ylogo++; //Fabkids logo down
  }
  else if(key=='a'||key=='A')
  {
        xlogo--; //Fabkids logo to the left
  }
  else if(key=='d'||key=='D')
  {
        xlogo++; //Fabkids logo to the right
  }
  //Pulsar la tecla E para salir del programa
  if(key=='e' || key=='E')
  {
    output.flush(); // Write the rest of the data in the text file
    output.close(); // Close file
    exit();//Exit program
  }
}